==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/fsx/kotlin/outputs/WindowsFileSystemSelfManagedActiveDirectory.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.fsx.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property dnsIps A list of up to two IP addresses of DNS servers or domain controllers in the self-managed AD directory. The IP addresses need to be either in the same VPC CIDR range as the file system or in the private IP version 4 (IPv4) address ranges as specified in [RFC 1918](https://tools.ietf.org/html/rfc1918).
 * @property domainName The fully qualified domain name of the self-managed AD directory. For example, `corp.example.com`.
 * @property fileSystemAdministratorsGroup The name of the domain group whose members are granted administrative privileges for the file system. Administrative privileges include taking ownership of files and folders, and setting audit controls (audit ACLs) on files and folders. The group that you specify must already exist in your domain. Defaults to `Domain Admins`.
 * @property organizationalUnitDistinguishedName The fully qualified distinguished name of the organizational unit within your self-managed AD directory that the Windows File Server instance will join. For example, `OU=FSx,DC=yourdomain,DC=corp,DC=com`. Only accepts OU as the direct parent of the file system. If none is provided, the FSx file system is created in the default location of your self-managed AD directory. To learn more, see [RFC 2253](https://tools.ietf.org/html/rfc2253).
 * @property password The password for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
 * @property username The user name for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
 */
public data class WindowsFileSystemSelfManagedActiveDirectory(
    public val dnsIps: List<String>,
    public val domainName: String,
    public val fileSystemAdministratorsGroup: String? = null,
    public val organizationalUnitDistinguishedName: String? = null,
    public val password: String,
    public val username: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.fsx.outputs.WindowsFileSystemSelfManagedActiveDirectory):
            WindowsFileSystemSelfManagedActiveDirectory = WindowsFileSystemSelfManagedActiveDirectory(
            dnsIps = javaType.dnsIps().map({ args0 -> args0 }),
            domainName = javaType.domainName(),
            fileSystemAdministratorsGroup = javaType.fileSystemAdministratorsGroup().map({ args0 ->
                args0
            }).orElse(null),
            organizationalUnitDistinguishedName = javaType.organizationalUnitDistinguishedName().map({ args0 ->
                args0
            }).orElse(null),
            password = javaType.password(),
            username = javaType.username(),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/fsx/kotlin/outputs/WindowsFileSystemSelfManagedActiveDirectory.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.fsx.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property dnsIps A list of up to two IP addresses of DNS servers or domain controllers in the self-managed AD directory. The IP addresses need to be either in the same VPC CIDR range as the file system or in the private IP version 4 (IPv4) address ranges as specified in [RFC 1918](https://tools.ietf.org/html/rfc1918).
 * @property domainName The fully qualified domain name of the self-managed AD directory. For example, `corp.example.com`.
 * @property fileSystemAdministratorsGroup The name of the domain group whose members are granted administrative privileges for the file system. Administrative privileges include taking ownership of files and folders, and setting audit controls (audit ACLs) on files and folders. The group that you specify must already exist in your domain. Defaults to `Domain Admins`.
 * @property organizationalUnitDistinguishedName The fully qualified distinguished name of the organizational unit within your self-managed AD directory that the Windows File Server instance will join. For example, `OU=FSx,DC=yourdomain,DC=corp,DC=com`. Only accepts OU as the direct parent of the file system. If none is provided, the FSx file system is created in the default location of your self-managed AD directory. To learn more, see [RFC 2253](https://tools.ietf.org/html/rfc2253).
 * @property password The password for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
 * @property username The user name for the service account on your self-managed AD domain that Amazon FSx will use to join to your AD domain.
 */
public data class WindowsFileSystemSelfManagedActiveDirectory(
    public val dnsIps: List<String>,
    public val domainName: String,
    public val fileSystemAdministratorsGroup: String? = null,
    public val organizationalUnitDistinguishedName: String? = null,
    public val password: String,
    public val username: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.fsx.outputs.WindowsFileSystemSelfManagedActiveDirectory): WindowsFileSystemSelfManagedActiveDirectory = WindowsFileSystemSelfManagedActiveDirectory(
            dnsIps = javaType.dnsIps().map({ args0 -> args0 }),
            domainName = javaType.domainName(),
            fileSystemAdministratorsGroup = javaType.fileSystemAdministratorsGroup().map({ args0 ->
                args0
            }).orElse(null),
            organizationalUnitDistinguishedName = javaType.organizationalUnitDistinguishedName().map({ args0 ->
                args0
            }).orElse(null),
            password = javaType.password(),
            username = javaType.username(),
        )
    }
}
